<template>
    <div class="home-container">
        <div style="height: 100%">
            <el-row class="homeCard">
                <div class="basic-line">
                    <span>场所名称：</span>
                    <el-input v-model="roomState.searchQuery.siteName" clearable filterable class="input-box" placeholder="场所名称">
                    </el-input>
                </div>
                <div class="basic-line">
                    <span>楼：</span>
                    <el-input v-model="roomState.searchQuery.floor" clearable filterable class="input-box" placeholder="楼">
                    </el-input>
                </div>
                <div class="basic-line">
                    <span>房间号：</span>
                    <el-input v-model="roomState.searchQuery.room" clearable filterable class="input-box" placeholder="房间号">
                    </el-input>
                </div>
                <div style="padding-bottom: 10px">
                    <el-button type="primary" @click="getRoomData">查询</el-button>
                    <el-button plain @click="reset">重置</el-button>
                </div>
            </el-row>
            <div class="homeCard">
                <div class="main-card">
                    <el-row class="cardTop">
                        <el-col :span="12" class="mainCardBtn">
                            <el-button type="primary" :icon="Plus" size="default" @click="openRoomDialog('新增', {})">新增</el-button>
                            <!--                            <el-button type="danger" :icon="Delete" size="default" plain>删除</el-button>-->
                        </el-col>
<!--                        <el-button type="primary" :icon="Refresh" size="default" />-->
                    </el-row>
                    <el-table ref="multipleTableRef" :data="roomState.roomData" style="width: 100%" height="calc(100% - 100px)" :header-cell-style="{ background: '#fafafa' }">
                        <el-table-column prop="siteName" label="场所名称"/>
                        <el-table-column prop="floor" label="实验室所在楼" />
                        <el-table-column prop="room" label="实验室所在房间"/>
                        <el-table-column prop="siteLiabilityPerson" label="场所责任人"/>
                        <el-table-column prop="safeLiabilityPerson" label="场所安全员"/>
                        <el-table-column prop="fireFacilities" label="有无消防设施">
                          <template #default="scope">
                            <span>{{scope.row.fireFacilities == 1?'有':'无'}}</span>
                          </template>
                        </el-table-column>
                        <el-table-column prop="partitionStatus" label="有无隔断">
                          <template #default="scope">
                            <span>{{scope.row.partitionStatus == 1?'有':'无'}}</span>
                          </template>
                        </el-table-column>
                        <el-table-column prop="siteType" label="场所性质"/>
                        <el-table-column prop="createTime" label="创建时间" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="createByUserName" label="创建人" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="updateTime" label="最后修改时间" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="updateByUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                        <el-table-column label="操作" width="150">
                            <template #default="scope">
                                <el-button size="small" text type="primary" :icon="Edit" @click="openRoomDialog('修改', scope.row)">编辑</el-button>
                                <el-button size="small" text type="danger" :icon="Delete" @click="onDelRoom(scope.row)">删除</el-button>
                            </template>
                        </el-table-column>
                    </el-table>
                    <div class="pageBtn">
                        <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="roomState.searchQuery.pageIndex" background v-model:page-size="roomState.searchQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="roomState.total" class="page-position"> </el-pagination>
                    </div>
                </div>
            </div>
        </div>
        <room-dialog ref="roomDialogRef" @refresh="getRoomData" :memberList="roomState.memberList" :typeList="roomState.typeList"></room-dialog>
    </div>
</template>

<script setup lang="ts">
import {defineAsyncComponent, onMounted, reactive, ref} from "vue";
import {roomApi} from "/@/api/basic/room";
import {personApi} from "/@/api/basic/person";
import {ElMessage, ElMessageBox} from "element-plus";
import { Edit, View, Plus, Delete } from '@element-plus/icons-vue';
import {equipmentApi} from "/@/api/basic/equipement";

const RoomDialog = defineAsyncComponent(() => import('./components/roomDialog.vue'));

const roomDialogRef = ref();

const roomState = reactive<RoomStateType>({
    roomData: [],
    memberList: [],
    typeList: [],
    searchQuery: {
        pageIndex: 1,
        pageSize: 10,
        siteName: '',
        floor: '',
        room: '',
    },
    total: 0,
    specialDeviceList: [
        {id: 1, name: '是'},
        {id:2, name: '否'}
    ],
    deviceUnitList: [
        {id:1, name: '台'},
        {id:2, name: '个'},
        {id:3, name: '件'}
    ]
})

const getAllMember = async ()=>{
  const res = await personApi().getAllPerson();
  if(res.data.code === 100){
    roomState.memberList = res.data.data
  }
}

const getAllType = async ()=>{
  const res = await roomApi().getAllType();
  if(res.data.code === 100){
    roomState.typeList = res.data.data
  }
}

const getRoomData = async () => {
    let res = await roomApi().getRoomByList(roomState.searchQuery);
    if(res.data.code === 100){
        roomState.roomData = res.data.data;
        roomState.total = res.data.total;
    }else{
        ElMessage({
            type: 'warning',
            message: res.data.msg
        });
    }
};

const openRoomDialog = (title: string, value: RoomType) => {
    roomDialogRef.value.showroomDialog(title, value, roomState.specialDeviceList);
};

const onDelRoom = (val: RoomType) => {
    ElMessageBox.confirm(`此操作将永久删除该场所：“${val.siteName}”，是否继续?`, '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
    })
        .then(async () => {
            let res = await roomApi().deleteRoomById({ id: val.id });
            if (res.data.code === 100) {
                ElMessage({
                    type: 'success',
                    duration: 2000,
                    message: '删除成功'
                });
                await getRoomData();
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        })
        .catch((error) => {
        });
}

const onHandleSizeChange = (val: number) => {
    roomState.searchQuery.pageSize = val;
    getRoomData();
};

const onHandleCurrentChange = (val: number) => {
    roomState.searchQuery.pageIndex = val;
    getRoomData();
};

const reset = () => {
    roomState.searchQuery = {
        pageIndex: 1,
        pageSize: 10,
        siteName: '',
        floor: '',
        room: '',
    }
};

onMounted(() => {
    getRoomData()
    getAllMember()
    getAllType()
})

</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 144px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
.stepItem {
    width: 100%;
    display: flex;
    align-items: flex-start;
    margin-bottom: 30px;
    margin-left: 30px;
    padding-bottom: 30px;
    border-left: 2px solid #ccc;
    &:first-of-type {
        margin-top: 30px;
    }
    &:last-of-type {
        margin-bottom: 0;
        border-left: none;
    }
    .stepNum {
        width: 30px;
        height: 30px;
        border-radius: 15px;
        box-sizing: border-box;
        color: #333;
        border: 1px solid #999;
        line-height: 28px;
        text-align: center;
        margin-right: 10px;
        margin-left: -16px;
        margin-top: -30px;
    }
    .stepCard {
        width: 100%;
        margin-top: -30px;

        .box-card {
            width: 100%;
            &:deep(.el-card__header) {
                padding: 10px 15px;
            }
            .card-header {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                & > div:first-of-type {
                    margin-right: 80px;
                    font-size: 18px;
                    font-weight: bold;
                }
            }
        }
    }
    &:hover .card-header {
        color: #0098f5;
    }
    &:hover .stepNum {
        border: 2px solid #0098f5;
        color: #0098f5;
    }
}

:deep(.el-date-editor) {
    width: 100%;
}
.el-select {
    width: 100%;
}
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
